@@ -11,14 +11,15 @@ class TCPLogstashHandler(SocketHandler, object):
     :param message_type: The type of the message (default logstash).
     :param fqdn; Indicates whether to show fully qualified domain name or not (default False).
     :param version: version of logstash event schema (default is 0).
+    :param tags: list of tags for a logger (default is None).
     """
 
-    def __init__(self, host, port=5959, message_type='logstash', fqdn=False, version=0):
+    def __init__(self, host, port=5959, message_type='logstash', tags=None, fqdn=False, version=0):
         super(TCPLogstashHandler, self).__init__(host, port)
         if version == 1:
-            self.formatter = formatter.LogstashFormatterVersion1(message_type, [], fqdn)
+            self.formatter = formatter.LogstashFormatterVersion1(message_type, tags, fqdn)
         else:
-            self.formatter = formatter.LogstashFormatterVersion0(message_type, [], fqdn)
+            self.formatter = formatter.LogstashFormatterVersion0(message_type, tags, fqdn)
 
     def makePickle(self, record):
         return self.formatter.format(record) + b'\n'
@@ -31,6 +32,7 @@ class UDPLogstashHandler(TCPLogstashHandler, DatagramHandler):
     :param message_type: The type of the message (default logstash).
     :param fqdn; Indicates whether to show fully qualified domain name or not (default False).
     :param version: version of logstash event schema (default is 0).
+    :param tags: list of tags for a logger (default is None).
     """
 
     def makePickle(self, record):
